@@ -76,13 +76,16 @@ def process_records(catalog,  # pylint: disable=too-many-branches
         for record in records:
             # If child object, add parent_id to record
             if parent_id and parent:
-                record[parent + '_id'] = parent_id
+                if parent == 'accounts':
+                    record['account_sid'] = parent_id
+                else:
+                    record[parent + '_id'] = parent_id
 
             # Transform record for Singer.io
             with Transformer() as transformer:
                 try:
                     transformed_record = transformer.transform(
-                        record,
+                        dict(record),
                         schema,
                         stream_metadata)
                 except Exception as err:
@@ -173,7 +176,8 @@ def sync_endpoint(
         date_window_days=None,
         parent=None,
         parent_id=None,
-        account_sid=None):
+        account_sid=None,
+        required_streams=None):
     static_params = endpoint_config.get('params', {})
     bookmark_query_field_from = endpoint_config.get('bookmark_query_field_from')
     bookmark_query_field_to = endpoint_config.get('bookmark_query_field_to')
@@ -202,8 +206,9 @@ def sync_endpoint(
 
         params = static_params  # adds in endpoint specific, sort, filter params
 
-        if bookmark_query_field_from and bookmark_query_field_to:
+        if bookmark_query_field_from:
             params[bookmark_query_field_from] = strftime(start_window)[:10]  # truncate date
+        if bookmark_query_field_to:
             params[bookmark_query_field_to] = strftime(end_window)[:10]  # truncate date
 
         # pagination: loop thru all pages of data using next (if not None)
@@ -248,8 +253,10 @@ def sync_endpoint(
                 break  # No data results
 
             # Get pagination details
-            if data.get("next_page_uri"):
-                next_url = endpoint_config.get("api_url") + data["next_page_uri"]
+            # Next page url key in API response is different for alerts and remaining streams
+            next_url_key_in_api_response = endpoint_config.get('pagination_key', 'next_page_uri')
+            if data.get(next_url_key_in_api_response):
+                next_url = endpoint_config.get("api_url") + data[next_url_key_in_api_response]
             else:
                 next_url = None
 
@@ -301,8 +308,9 @@ def sync_endpoint(
             children = endpoint_config.get('children')
             if children:
                 for child_stream_name, child_endpoint_config in children.items():
-                    # will this work if only grandchildren are selected
-                    if child_stream_name in selected_streams:
+                    # Following check will make sure tap extracts the data for all the child streams
+                    # even if the parent isn't selected
+                    if child_stream_name in selected_streams or child_stream_name in required_streams:
                         LOGGER.info('START Syncing: {}'.format(child_stream_name))
                         write_schema(catalog, child_stream_name)
                         # For each parent record
@@ -333,7 +341,7 @@ def sync_endpoint(
                                         ParentId=parent_id)
                             elif child_stream_name == 'dependent_phone_numbers':
                                 child_path = child_endpoint_config.get('path').format(
-                                    ParentId=parent_id, AccountSid=config.get('account_sid'))
+                                    ParentId=parent_id, AccountSid=record.get('account_sid'))
                             else:
                                 child_path = record.get('_subresource_uris', {}).get(
                                     child_endpoint_config.get('sub_resource_key',
@@ -355,10 +363,11 @@ def sync_endpoint(
                                     selected_streams=selected_streams,
                                     # The child endpoint may be an endpoint that needs to window
                                     # so we'll re-pull from the config here (or pass in the default)
-                                    date_window_days=int(config.get('date_window_days', '30')),
+                                    date_window_days=int(config.get('date_window_days') or'30'),
                                     parent=child_endpoint_config.get('parent'),
                                     parent_id=parent_id,
-                                    account_sid=account_sid)
+                                    account_sid=account_sid,
+                                    required_streams=required_streams)
                             else:
                                 LOGGER.info(
                                     'No child stream {} for parent stream {} in subresource uris'
@@ -486,7 +495,8 @@ def sync(client, config, catalog, state):
                 endpoint_config=endpoint_config,
                 bookmark_field=bookmark_field,
                 selected_streams=selected_streams,
-                date_window_days=int(config.get('date_window_days', '30')))
+                date_window_days=int(config.get('date_window_days') or '30'),
+                required_streams=required_streams)
 
             update_currently_syncing(state, None)
             LOGGER.info('FINISHED Syncing: {}, total_records: {}'.format(
